==> satellite_bucket-0.0.1.tar.gz: satellite_bucket-0.0.1/README.md <==
<div align="center">

|                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| ----------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Deployment        | [![PyPI](https://badge.fury.io/py/sat-bucket.svg?style=flat)](https://pypi.org/project/sat-bucket/) [![Conda](https://img.shields.io/conda/vn/conda-forge/sat-bucket.svg?logo=conda-forge&logoColor=white&style=flat)](https://anaconda.org/conda-forge/sat-bucket)                                                                                                                                                                                                                                                                                                                                                                                                                       |
| Activity          | [![PyPI Downloads](https://img.shields.io/pypi/dm/sat-bucket.svg?label=PyPI%20downloads&style=flat)](https://pypi.org/project/sat-bucket/) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/sat-bucket.svg?label=Conda%20downloads&style=flat)](https://anaconda.org/conda-forge/sat-bucket)                                                                                                                                                                                                                                                                                                                                                                               |
| Python Versions   | [![Python Versions](https://img.shields.io/badge/Python-3.10%20%203.11%20%203.12%20%203.13-blue?style=flat)](https://www.python.org/downloads/)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| Supported Systems | [![Linux](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests.yaml?label=Linux&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![macOS](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests.yaml?label=macOS&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![Windows](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests_windows.yaml?label=Windows&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests_windows.yaml)                                      |
| Project Status    | [![Project Status](https://www.repostatus.org/badges/latest/active.svg?style=flat)](https://www.repostatus.org/#active)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| Build Status      | [![Tests](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml/badge.svg?style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![Lint](https://github.com/ghiggi/sat-bucket/actions/workflows/lint.yaml/badge.svg?style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/lint.yaml) [![Docs](https://readthedocs.org/projects/sat-bucket/badge/?version=latest&style=flat)](https://sat-bucket.readthedocs.io/en/latest/)                                                                                                                                                                                                            |
| Linting           | [![Black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat)](https://github.com/psf/black) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat)](https://github.com/astral-sh/ruff) [![Codespell](https://img.shields.io/badge/Codespell-enabled-brightgreen?style=flat)](https://github.com/codespell-project/codespell)                                                                                                                                                                                                                                                             |
| Code Coverage     | [![Coveralls](https://coveralls.io/repos/github/ghiggi/sat-bucket/badge.svg?branch=main&style=flat)](https://coveralls.io/github/ghiggi/sat-bucket?branch=main) [![Codecov](https://codecov.io/gh/ghiggi/sat-bucket/branch/main/graph/badge.svg?style=flat)](https://codecov.io/gh/ghiggi/sat-bucket)                                                                                                                                                                                                                                                                                                                                                                                     |
| Code Quality      | [![Codefactor](https://www.codefactor.io/repository/github/ghiggi/sat-bucket/badge?style=flat)](https://www.codefactor.io/repository/github/ghiggi/sat-bucket) [![Codebeat](https://codebeat.co/badges/236abcf2-cbae-4ca9-8a2d-3b70495bb16b?style=flat)](https://codebeat.co/projects/github-com-ghiggi-sat-bucket-main) [![Codacy](https://app.codacy.com/project/badge/Grade/bee842cb10004ad8bb9288256f2fc8af?style=flat)](https://app.codacy.com/gh/ghiggi/sat-bucket/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade) [![Codescene](https://codescene.io/projects/36767/status-badges/code-health?style=flat)](https://codescene.io/projects/36767) |
| License           | [![License](https://img.shields.io/github/license/ghiggi/sat-bucket?style=flat)](https://github.com/ghiggi/sat-bucket/blob/main/LICENSE)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Community         | [![Slack](https://img.shields.io/badge/Slack-sat-bucket-green.svg?logo=slack&style=flat)](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg) [![GitHub Discussions](https://img.shields.io/badge/GitHub-Discussions-green?logo=github&style=flat)](https://github.com/ghiggi/sat-bucket/discussions)                                                                                                                                                                                                                                                                                                                                                      |
| Citation          | [![DOI](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |

[**Slack**](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg) | [**Documentation**](https://sat-bucket.readthedocs.io/en/latest/)

<div align="left">

## 🚀 Quick start

sat-bucket provides an easy-to-use way to rearchive satellite data archives in order to blazing fast point/regional temporal queries as well as construct
gridded data cube.

______________________________________________________________________

### 📖 Explore the sat-bucket documentation

To discover all sat-bucket features,
please read the software documentation available at [https://sat-bucket.readthedocs.io/en/latest/](https://sat-bucket.readthedocs.io/en/latest/).

If you are new to sat-bucket, we recommend starting with the following pages:

- TODO
-

All sat-bucket tutorials are available as Jupyter Notebooks in the [`tutorial`](https://github.com/ghiggi/sat-bucket/tree/main/tutorials) directory.

______________________________________________________________________

## 🛠️ Installation

### conda

sat-bucket can be installed via [conda][conda_link] on Linux, Mac, and Windows.
Install the package by typing the following command in the terminal:

```bash
conda install sat-bucket
```

In case conda-forge is not set up for your system yet, see the easy to follow instructions on [conda-forge][conda_forge_link].

### pip

sat-bucket can be installed also via [pip][pip_link] on Linux, Mac, and Windows.
On Windows you can install [WinPython][winpy_link] to get Python and pip running.
Prior installation of sat-bucket, try to install to `cartopy>=0.21.0` package to ensure there are not [GEOS](https://libgeos.org/) library version incompatibilities.
If you can't solve the problems and install cartopy with pip, you should install at least cartopy with conda using `conda install cartopy>=0.21.0`.

Then, install the sat-bucket package by typing the following command in the terminal:

```bash
pip install sat-bucket
```

To install the latest development version via pip, see the [documentation][dev_install_link].

## 💭 Feedback and Contributing Guidelines

If you aim to contribute your data or discuss the future development of sat-bucket,
we highly suggest to join the [**Slack Workspace**](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg)

Feel free to also open a [GitHub Issue](https://github.com/ghiggi/sat-bucket/issues) or a [GitHub Discussion](https://github.com/ghiggi/sat-bucket/discussions) specific to your questions or ideas.

## Citation

If you are using sat-bucket in your publication please cite our Zenodo repository:

> Ghiggi Gionata. ghiggi/sat-bucket. Zenodo. [![<https://doi.org/10.5281/zenodo.7753488>](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)

If you want to cite a specific software version, have a look at the [Zenodo site](https://doi.org/10.5281/zenodo.7753488).

## License

The content of this repository is released under the terms of the [MIT license](LICENSE).

[conda_forge_link]: https://github.com/conda-forge/sat-bucket-feedstock#installing-sat-bucket
[conda_link]: https://docs.conda.io/en/latest/miniconda.html
[dev_install_link]: https://sat-bucket.readthedocs.io/en/latest/02_installation.html#installation-for-contributors
[pip_link]: https://pypi.org/project/sat-bucket
[winpy_link]: https://winpython.github.io/

==> satellite_bucket-0.0.3.tar.gz: satellite_bucket-0.0.3/README.md <==
<div align="center">

|                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| ----------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Deployment        | [![PyPI](https://badge.fury.io/py/satellite-bucket.svg?style=flat)](https://pypi.org/project/sat-bucket/) [![Conda](https://img.shields.io/conda/vn/conda-forge/satellite-bucket.svg?logo=conda-forge&logoColor=white&style=flat)](https://anaconda.org/conda-forge/satellite-bucket)                                                                                                                                                                                                                                                                                                                                                                                                     |
| Activity          | [![PyPI Downloads](https://img.shields.io/pypi/dm/satellite-bucket.svg?label=PyPI%20downloads&style=flat)](https://pypi.org/project/satellite-bucket/) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/satellite-bucket.svg?label=Conda%20downloads&style=flat)](https://anaconda.org/conda-forge/satellite-bucket)                                                                                                                                                                                                                                                                                                                                                       |
| Python Versions   | [![Python Versions](https://img.shields.io/badge/Python-3.10%20%203.11%20%203.12%20%203.13-blue?style=flat)](https://www.python.org/downloads/)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| Supported Systems | [![Linux](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests.yaml?label=Linux&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![macOS](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests.yaml?label=macOS&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![Windows](https://img.shields.io/github/actions/workflow/status/ghiggi/sat-bucket/.github/workflows/tests_windows.yaml?label=Windows&style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests_windows.yaml)                                      |
| Project Status    | [![Project Status](https://www.repostatus.org/badges/latest/active.svg?style=flat)](https://www.repostatus.org/#active)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   |
| Build Status      | [![Tests](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml/badge.svg?style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/tests.yaml) [![Lint](https://github.com/ghiggi/sat-bucket/actions/workflows/lint.yaml/badge.svg?style=flat)](https://github.com/ghiggi/sat-bucket/actions/workflows/lint.yaml) [![Docs](https://readthedocs.org/projects/sat-bucket/badge/?version=latest&style=flat)](https://sat-bucket.readthedocs.io/en/latest/)                                                                                                                                                                                                            |
| Linting           | [![Black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat)](https://github.com/psf/black) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat)](https://github.com/astral-sh/ruff) [![Codespell](https://img.shields.io/badge/Codespell-enabled-brightgreen?style=flat)](https://github.com/codespell-project/codespell)                                                                                                                                                                                                                                                             |
| Code Coverage     | [![Coveralls](https://coveralls.io/repos/github/ghiggi/sat-bucket/badge.svg?branch=main&style=flat)](https://coveralls.io/github/ghiggi/sat-bucket?branch=main) [![Codecov](https://codecov.io/gh/ghiggi/sat-bucket/branch/main/graph/badge.svg?style=flat)](https://codecov.io/gh/ghiggi/sat-bucket)                                                                                                                                                                                                                                                                                                                                                                                     |
| Code Quality      | [![Codefactor](https://www.codefactor.io/repository/github/ghiggi/sat-bucket/badge?style=flat)](https://www.codefactor.io/repository/github/ghiggi/sat-bucket) [![Codebeat](https://codebeat.co/badges/236abcf2-cbae-4ca9-8a2d-3b70495bb16b?style=flat)](https://codebeat.co/projects/github-com-ghiggi-sat-bucket-main) [![Codacy](https://app.codacy.com/project/badge/Grade/bee842cb10004ad8bb9288256f2fc8af?style=flat)](https://app.codacy.com/gh/ghiggi/sat-bucket/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade) [![Codescene](https://codescene.io/projects/67023/status-badges/code-health?style=flat)](https://codescene.io/projects/67023) |
| License           | [![License](https://img.shields.io/github/license/ghiggi/sat-bucket?style=flat)](https://github.com/ghiggi/sat-bucket/blob/main/LICENSE)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |
| Community         | [![Slack](https://img.shields.io/badge/Slack-sat-bucket-green.svg?logo=slack&style=flat)](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg) [![GitHub Discussions](https://img.shields.io/badge/GitHub-Discussions-green?logo=github&style=flat)](https://github.com/ghiggi/sat-bucket/discussions)                                                                                                                                                                                                                                                                                                                                                      |
| Citation          | [![DOI](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |

[**Slack**](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg) | [**Documentation**](https://sat-bucket.readthedocs.io/en/latest/)

<div align="left">

## 🚀 Quick start

sat-bucket provides an easy-to-use way to rearchive satellite data archives in order to blazing fast point/regional temporal queries as well as construct
gridded data cube.

______________________________________________________________________

### 📖 Explore the sat-bucket documentation

To discover all sat-bucket features,
please read the software documentation available at [https://sat-bucket.readthedocs.io/en/latest/](https://sat-bucket.readthedocs.io/en/latest/).

If you are new to sat-bucket, we recommend starting with the following pages:

- TODO
-

All sat-bucket tutorials are available as Jupyter Notebooks in the [`tutorial`](https://github.com/ghiggi/sat-bucket/tree/main/tutorials) directory.

______________________________________________________________________

## 🛠️ Installation

### conda

sat-bucket can be installed via [conda][conda_link] on Linux, Mac, and Windows.
Install the package by typing the following command in the terminal:

```bash
conda install satellite-bucket
```

In case conda-forge is not set up for your system yet, see the easy to follow instructions on [conda-forge][conda_forge_link].

### pip

sat-bucket can be installed also via [pip][pip_link] on Linux, Mac, and Windows.
On Windows you can install [WinPython][winpy_link] to get Python and pip running.
Prior installation of sat-bucket, try to install to `cartopy>=0.21.0` package to ensure there are not [GEOS](https://libgeos.org/) library version incompatibilities.
If you can't solve the problems and install cartopy with pip, you should install at least cartopy with conda using `conda install cartopy>=0.21.0`.

Then, install the sat-bucket package by typing the following command in the terminal:

```bash
pip install satellite-bucket
```

To install the latest development version via pip, see the [documentation][dev_install_link].

## 💭 Feedback and Contributing Guidelines

If you aim to contribute your data or discuss the future development of sat-bucket,
we highly suggest to join the [**Slack Workspace**](https://join.slack.com/t/gpmapi/shared_invite/zt-28vkxzjs1-~cIYci2o3G0qEEoQJVMQRg)

Feel free to also open a [GitHub Issue](https://github.com/ghiggi/sat-bucket/issues) or a [GitHub Discussion](https://github.com/ghiggi/sat-bucket/discussions) specific to your questions or ideas.

## Citation

If you are using sat-bucket in your publication please cite our Zenodo repository:

> Ghiggi Gionata. ghiggi/sat-bucket. Zenodo. [![<https://doi.org/10.5281/zenodo.7753488>](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)

If you want to cite a specific software version, have a look at the [Zenodo site](https://doi.org/10.5281/zenodo.7753488).

## License

The content of this repository is released under the terms of the [MIT license](LICENSE).

[conda_forge_link]: https://github.com/conda-forge/sat-bucket-feedstock#installing-sat-bucket
[conda_link]: https://docs.conda.io/en/latest/miniconda.html
[dev_install_link]: https://sat-bucket.readthedocs.io/en/latest/02_installation.html#installation-for-contributors
[pip_link]: https://pypi.org/project/sat-bucket
[winpy_link]: https://winpython.github.io/
